--drop
DROP TABLE eladasok;
DROP TABLE szamlak;
DROP TABLE vasarlok;
DROP TABLE kiadvanyok;
DROP TABLE albumok;

--create tables
CREATE TABLE albumok (
    eloado VARCHAR(255) NOT NULL,
    cim VARCHAR(255) NOT NULL,
    mufaj VARCHAR(255)
);
ALTER TABLE albumok ADD CONSTRAINT pk_albumok PRIMARY KEY (eloado, cim);

CREATE TABLE kiadvanyok (
	eloado VARCHAR(255) NOT NULL,
	cim VARCHAR(255) NOT NULL,
	kiadvanyszam VARCHAR(255) NOT NULL,
	kiado VARCHAR(255),
	formatum VARCHAR(255),
	kiadas_eve NUMBER,
	ar NUMBER
);
ALTER TABLE kiadvanyok ADD CONSTRAINT pk_kiadvanyok PRIMARY KEY (eloado, cim, kiadvanyszam);
ALTER TABLE kiadvanyok ADD CONSTRAINT fk_kiadvanyok FOREIGN KEY (eloado, cim) REFERENCES albumok(eloado, cim) ON DELETE CASCADE;

CREATE TABLE vasarlok (
	nev VARCHAR(255) NOT NULL,
	cim VARCHAR(255) NOT NULL,
	telefonszam VARCHAR(255),
	email VARCHAR(255)
);
ALTER TABLE vasarlok ADD CONSTRAINT pk_vasarlok PRIMARY KEY (nev, cim);

CREATE TABLE szamlak (
	szamlaszam VARCHAR(255) NOT NULL,
	vasarlo_neve VARCHAR(255) NOT NULL,
	vasarlo_cime VARCHAR (255) NOT NULL
);
ALTER TABLE szamlak ADD CONSTRAINT pk_szamlak PRIMARY KEY (szamlaszam);
ALTER TABLE szamlak ADD CONSTRAINT fk_szamlak FOREIGN KEY (vasarlo_neve, vasarlo_cime) REFERENCES vasarlok(nev, cim) ON DELETE CASCADE;

CREATE TABLE eladasok (
	szamlaszam VARCHAR(255) NOT NULL,
	eloado VARCHAR(255) NOT NULL,
	cim VARCHAR(255) NOT NULL,
	kiadvanyszam VARCHAR(255) NOT NULL,
	idopont TIMESTAMP
);
ALTER TABLE eladasok ADD CONSTRAINT pk_eladasok PRIMARY KEY (szamlaszam, eloado, cim, kiadvanyszam);
ALTER TABLE eladasok ADD CONSTRAINT fk_eladasok_szamla FOREIGN KEY (szamlaszam) REFERENCES szamlak(szamlaszam) ON DELETE CASCADE;
ALTER TABLE eladasok ADD CONSTRAINT fk_eladasok_album FOREIGN KEY (eloado, cim, kiadvanyszam) REFERENCES kiadvanyok(eloado, cim, kiadvanyszam) ON DELETE CASCADE;

CREATE GLOBAL TEMPORARY TABLE eladasok_temp 
ON COMMIT PRESERVE ROWS 
AS SELECT * FROM eladasok;

--create on update triggers
CREATE OR REPLACE TRIGGER albumok_onupdate
AFTER UPDATE OF eloado, cim
ON albumok
FOR EACH ROW
BEGIN
    UPDATE kiadvanyok
    SET kiadvanyok.eloado = :new.eloado,
        kiadvanyok.cim = :new.cim
    WHERE kiadvanyok.cim = :old.cim
        AND kiadvanyok.eloado = :old.eloado;
    UPDATE eladasok
    SET eladasok.eloado = :new.eloado,
        eladasok.cim = :new.cim
    WHERE eladasok.eloado = :old.eloado
		AND eladasok.cim = :old.cim;
END;
/

CREATE OR REPLACE TRIGGER kiadvanyok_onupdate
AFTER UPDATE OF kiadvanyszam
ON kiadvanyok
FOR EACH ROW
BEGIN
	UPDATE eladasok
	SET eladasok.kiadvanyszam = :new.kiadvanyszam
	WHERE eladasok.kiadvanyszam = :old.kiadvanyszam;
END;
/

CREATE OR REPLACE TRIGGER vasarlok_onupdate
AFTER UPDATE OF nev, cim
ON vasarlok
FOR EACH ROW
BEGIN
	UPDATE szamlak
	SET szamlak.vasarlo_neve = :new.nev,
		szamlak.vasarlo_cime = :new.cim
	WHERE szamlak.vasarlo_neve = :old.nev
		AND szamlak.vasarlo_cime = :old.cim;
END;
/

CREATE OR REPLACE TRIGGER szamlak_onupdate
AFTER UPDATE OF szamlaszam
ON szamlak
FOR EACH ROW
BEGIN
	UPDATE eladasok
	SET eladasok.szamlaszam = :new.szamlaszam
	WHERE eladasok.szamlaszam = :old.szamlaszam;
END;
/

--insert data
INSERT INTO albumok VALUES ('Daft Punk', 'Random Access Memories', 'Electronic, Funk / Soul, Pop');
INSERT INTO albumok VALUES ('Fleetwood Mac', 'Rumours', 'Rock');
INSERT INTO albumok VALUES ('Daft Punk', 'Homework', 'Electronic');
INSERT INTO albumok VALUES ('Pink Floyd', 'The Dark Side of The Moon', 'Rock');
INSERT INTO albumok VALUES ('Stardust', 'Music Sounds Better With You', 'Electronic');
INSERT INTO albumok VALUES ('Michael Jackson', 'Thriller', 'Electronic, Funk / Soul, Pop');

INSERT INTO kiadvanyok VALUES ('Daft Punk', 'Random Access Memories', '88883716861', 'Columbia', '2x Bakelit', 2013, 13.76);
INSERT INTO kiadvanyok VALUES ('Fleetwood Mac', 'Rumours', 'BSK 3010', 'Warner Bros. Records', 'Bakelit', 1977, 2.02);
INSERT INTO kiadvanyok VALUES ('Daft Punk', 'Homework', 'V 2821', 'Virgin', '2x Bakelit', 1997, 13.76);
INSERT INTO kiadvanyok VALUES ('Pink Floyd', 'The Dark Side of The Moon', 'SMAS-11163', 'Harvest', 'Bakelit', 1973, 9.11);
INSERT INTO kiadvanyok VALUES ('Daft Punk', 'Homework', 'CDV 2821', 'Virgin', 'CD', 1997, 1.31);
INSERT INTO kiadvanyok VALUES ('Stardust', 'Music Sounds Better With You', 'Roulé 305', 'Roulé 305', 'Bakelit', 1998, 6.35);
INSERT INTO kiadvanyok VALUES ('Michael Jackson', 'Thriller', 'QE 38112', 'Epic', 'Bakelit', 1982, 0.79);
INSERT INTO kiadvanyok VALUES ('Michael Jackson', 'Thriller', '40-85930', 'Epic', 'Kazetta', 1982, 5.08);
INSERT INTO kiadvanyok VALUES ('Michael Jackson', 'Thriller', 'EK 38112', 'Epic', 'CD', 1983, 39.59);

INSERT INTO vasarlok VALUES ('Gipsz Jakab', '1119 Budapest, Kossuth utca 15.', '+36 30 792 1269', 'gipsz.jakab@outlook.com');
INSERT INTO vasarlok VALUES ('Teszt Elek', '5001 Szolnok, Széchényi út 26/b.', '+36 20 987 3654', 'elek.teszt@freemail.hu');

INSERT INTO szamlak VALUES ('84521458-00000254-88745234', 'Gipsz Jakab', '1119 Budapest, Kossuth utca 15.');
INSERT INTO szamlak VALUES ('53214569-00000369-87425991', 'Teszt Elek', '5001 Szolnok, Széchényi út 26/b.');

--import dll
GRANT CREATE ANY LIBRARY, 
      EXECUTE ANY TYPE,
      EXECUTE ANY PROCEDURE,
      ALTER ANY LIBRARY, 
      DROP ANY LIBRARY, 
      DROP ANY TYPE,
      DROP ANY PROCEDURE
  TO magyar;

CREATE OR REPLACE LIBRARY EmailLIB AS
   '/u01/app/oracle/product/11.2.0/xe/bin/EmailSender.dll';

CREATE OR REPLACE FUNCTION SENDRECEIPT
 (name IN VARCHAR2, email IN VARCHAR2, releases IN VARCHAR2)
 RETURN BINARY_INTEGER
 AS EXTERNAL
    LIBRARY EmailLib
    NAME "SendReceipt"
    LANGUAGE C
    PARAMETERS (name STRING, email STRING, releases STRING);

--import users
begin
wwv_flow_fnd_user_api.create_fnd_user (
  p_user_id      => '2546128291335736',
  p_user_name    => 'ADMINISTRATOR',
  p_first_name   => '',
  p_last_name    => '',
  p_description  => '',
  p_email_address=> 'admin@vinylscratch.hu',
  p_web_password => 'B91E5C8DE4653D8F2990644E33466C11',
  p_web_password_format => 'HEX_ENCODED_DIGEST_V2',
  p_group_ids                    => '',
  p_developer_privs              => '',
  p_default_schema               => 'MAGYAR',
  p_account_locked               => 'N',
  p_account_expiry               => to_date('201412040000','YYYYMMDDHH24MI'),
  p_failed_access_attempts       => 0,
  p_change_password_on_first_use => 'N',
  p_first_password_use_occurred  => 'N',
  p_allow_app_building_yn        => 'N',
  p_allow_sql_workshop_yn        => 'N',
  p_allow_websheet_dev_yn        => 'N',
  p_allow_team_development_yn    => 'Y',
  p_allow_access_to_schemas      => '');
end;
/
begin
wwv_flow_fnd_user_api.create_fnd_user (
  p_user_id      => '2546405220338606',
  p_user_name    => 'ELADO',
  p_first_name   => '',
  p_last_name    => '',
  p_description  => '',
  p_email_address=> 'elado@vinylscratch.hu',
  p_web_password => '3F1FDDB3C5792332876B0769115E71D3',
  p_web_password_format => 'HEX_ENCODED_DIGEST_V2',
  p_group_ids                    => '',
  p_developer_privs              => '',
  p_default_schema               => 'MAGYAR',
  p_account_locked               => 'N',
  p_account_expiry               => to_date('201412040000','YYYYMMDDHH24MI'),
  p_failed_access_attempts       => 0,
  p_change_password_on_first_use => 'Y',
  p_first_password_use_occurred  => 'N',
  p_allow_app_building_yn        => 'N',
  p_allow_sql_workshop_yn        => 'N',
  p_allow_websheet_dev_yn        => 'N',
  p_allow_team_development_yn    => 'Y',
  p_allow_access_to_schemas      => '');
end;
/
